# Import Inspector
- Memory Profiling of Imports:
- CPU and Execution Time Tracking:
- Profiling Summary and Optional Details:

#### Memory
```
import-inspector my_script.py --memory
```

#### CPU
```
import-inspector my_script.py --cpu
```

#### Detailed
```
import-inspector my_script.py --detailed
```